---
name: Bug report
about: Create a bug report to help us improve
title: '[BUG] '
labels: bug
assignees: ''

---

# Describe the bug
A clear and concise description of what the bug is, what you expected to happen versus what you got. You can add here a paste of any errors or warnings you got.

# Session information
Please run paste here the output of running the following in your notebook/terminal:

```python
# Sessions info
import session_info
session_info.show(html=False, dependencies=True)
```

# Screenshots
If applicable, add screenshots to help explain your problem.

# Reproducible example
Please provide us with (any that apply):
1. **Code**: code we can run to reproduce the issue (in terminal or python notebook)
2. **Reference**: If the issue is in a tutorial, please provide the link to it, and the exact place in which the code fails.

# Additional context
Add any other context about the problem here that might help us solve it.
